# RocketlaneApp MCP Server

An MCP Server for the RocketlaneApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the RocketlaneApp API.


| Tool | Description |
|------|-------------|
| `get_time_entry` | Get a time entry |
| `update_time_entry` | Update a time entry |
| `delete_time_entry` | Delete a time entry |
| `get_task` | Get task by Id |
| `update_task` | Update task by Id |
| `delete_task` | Delete task by Id |
| `get_space` | Get space by Id |
| `update_space` | Update space by Id |
| `delete_space` | Delete space by Id |
| `get_space_document` | Get space document by Id |
| `update_space_document` | Update space document by Id |
| `delete_space_document` | Delete space document by Id |
| `get_project` | Get project by Id |
| `update_project` | Update project by Id |
| `delete_project` | Delete project by Id |
| `get_phase` | Get phase by Id |
| `update_phase` | Update phase by Id |
| `delete_phase` | Delete phase by Id |
| `get_field` | Get field by Id |
| `update_field` | Update field by Id |
| `delete_field` | Delete field by Id |
| `get_all_timeoffs` | Get all time-offs |
| `create_timeoff` | Create a time-off |
| `get_all_time_entries` | Get all time entries |
| `create_time_entry` | Create a time entry |
| `remove_followers_from_task` | Remove followers from a task by Id |
| `remove_dependencies_from_task` | Remove dependencies from a task by Id |
| `remove_assignees_from_task` | Remove assignees from a task by Id |
| `move_task_to_given_phase` | Move a task to the phase by Id |
| `add_followers_to_task` | Add followers to a task by Id |
| `add_dependencies_to_task` | Add dependencies to a task by Id |
| `add_assignee_to_task` | Add assignees to a task by Id |
| `get_all_tasks` | Get all tasks |
| `create_task` | Create a task |
| `get_all_spaces` | Get all spaces |
| `create_space` | Create a space |
| `get_all_space_documents` | Get all space documents |
| `create_space_document` | Create a space document |
| `unassign_placeholders` | Un assign placeholders from an user in a project |
| `remove_members` | Remove members from a project |
| `import_template` | Import a template to a project |
| `assign_placeholders` | Assign placeholders to an user in a project |
| `archive_project` | Archive project by Id |
| `add_members` | Add members to a project |
| `get_all_projects` | Get all projects |
| `create_project` | Create a project |
| `get_all_phases` | Get all phases |
| `create_phase` | Create a phase |
| `update_field_option` | Update field Option |
| `add_field_option` | Add field Option |
| `get_all_fields` | Get all fields |
| `create_field` | Create a Field |
| `get_user` | Get user by Id |
| `get_all_users` | Get all users |
| `get_timeoff` | Get time-off by Id |
| `delete_timeoff` | Delete a time-off |
| `search_time_entries` | Search time entries |
| `get_time_entry_categories` | Get time entry categories |
| `get_all_resource_allocations` | Get all Resource allocations |
